.. toctree::
   :maxdepth: 2

.. include:: ../README.rst


API Reference
-------------

.. automodule:: actors
    :members:
    :undoc-members:
    :inherited-members:



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
